<?php

    if ( !defined( 'ABSPATH' ) ) exit;
    
    if ( ! class_exists( 'request_a_date_403_settings' ) ) {
    
        class request_a_date_403_settings  extends WC_Integration {
            
            private $options;
            
            public function __construct() {
                global $woocommerce;
                $this->id                 = 'request_a_date';
                $this->method_title       = __( 'Request a date in payment', 'request-a-date' );
                $this->method_description = __( 'Request a date in the WooCommerce payment page.', 'request-a-date' );

                $page = '';
                if (isset($_REQUEST['page'])) { $page = sanitize_text_field($_REQUEST['page']); }
                $tab = '';
                if (isset($_REQUEST['tab'])) { $tab = sanitize_text_field($_REQUEST['tab']); }
                $section = '';
                if (isset($_REQUEST['section'])) { $section = sanitize_text_field($_REQUEST['section']); }

                $this->init_form_fields();
                $this->init_settings();

                // Actions.
                add_action( 'woocommerce_update_options_integration_' .  $this->id, array( $this, 'process_admin_options' ) );
                
                wp_register_style( 'request-a-date', '');
                wp_add_inline_style( 'request-a-date', '.form-table td.forminp {padding-bottom: 0;}' );
                wp_enqueue_style( 'request-a-date' );

            }

            public function init_form_fields() {

                $defaults = request_a_date_403_get_options();

            	$this->form_fields = array(
            		'woocommerce_checkout' => array(
                        'title'             => __('Show in checkout', 'request-a-date'),
            			'type'              => 'select',
                        'description'       => __( 'Mark where to appear on the checkout page!', 'request-a-date'),
            			'desc_tip'          => false,
                        'options'           => array(
                                '' => __('Do not show', 'request-a-date'),
                                'woocommerce_after_checkout_billing_form' => __('After checkout billing form', 'request-a-date'),
                                'woocommerce_after_checkout_shipping_form' => __('After checkout shipping form', 'request-a-date'),
                                'woocommerce_before_order_notes' => __('Before order notes', 'request-a-date'),
                                'woocommerce_after_order_notes' => __('After order notes', 'request-a-date'),
                                'woocommerce_review_order_before_shipping' => __('Review order before shipping', 'request-a-date'),
                                'woocommerce_review_order_after_shipping' => __('Review order after shipping', 'request-a-date'),
                                'woocommerce_review_order_after_order_total' => __('Review order after order total', 'request-a-date')
                            )
            		),                    
                    'use_shipping' => array(
                        'title'             => __('Use for shipping', 'request-a-date'),
            			'type'              => 'ships',
                        'description'       => __( 'Check the shipping methods where you want to use the date field!', 'request-a-date'),
            			'desc_tip'          => false
                    )
            	);            

                $this->form_fields['in_table'] = array(
                        'title'             => __('Render in table', 'request-a-date'),
                        'type'              => 'checkbox',
                        'description'       => __( 'If you use a spreadsheet to display WooCommerce <em>(this is the default)</em>, check this!', 'request-a-date'),
                        'desc_tip'          => false,
                        'default'           => $defaults['in_table']
                    );
                $this->form_fields['title'] = array(
                        'title'             => __('Title', 'request-a-date'),
                        'type'              => 'text',
                        'description'       => __( 'Label to select the date', 'request-a-date'),
                        'desc_tip'          => false,
                        'default'           => $defaults['title']
                    );
                $this->form_fields['description'] = array(
                        'title'             => __('Description', 'request-a-date'),
                        'type'              => 'textarea',
                        'description'       => __( 'Description for date selection.', 'request-a-date'),
                        'desc_tip'          => false,
                        'default'           => $defaults['description']
                    );
                $this->form_fields['date_format'] = array(
                        'title'             => __('Date format', 'request-a-date'),
                        'type'              => 'text',
                        'description'       => __( 'Date display format (WordPress standard)', 'request-a-date'),
                        'desc_tip'          => false,
                        'css'               => 'width:200px;',
                        'default'           => $defaults['date_format']
                    );
                $this->form_fields['intime'] = array(
                        'title'             => __('Round of the day', 'request-a-date'),
                        'type'              => 'time',
                        'description'       => __( 'After this time, the next day is current.', 'request-a-date'),
                        'desc_tip'          => false,
                        'css'               => 'width:100px;',
                        'default'           => $defaults['intime']
                    );
                $this->form_fields['shift'] = array(
                        'title'             => __('Shift day(s)', 'request-a-date'),
                        'type'              => 'number',
                        'description'       => __( 'You can select a date later than this number of days.', 'request-a-date'),
                        'desc_tip'          => false,
                        'css'               => 'width:80px;',
                        'default'           => $defaults['shift'],
                        'custom_attributes' => array('min' => 0)
                    );
                $this->form_fields['reorder'] = array(
                        'title'             => __('Reorder monitoring', 'request-a-date'),
                        'type'              => 'number',
                        'description'       => __( 'If a product needs to be reordered <em>(not enough in stock)</em>, the earliest date that can be selected must be this many days later.', 'request-a-date'),
                        'desc_tip'          => false,
                        'css'               => 'width:80px;',
                        'default'           => $defaults['reorder'],
                        'custom_attributes' => array('min' => 0)
                    );
                $this->form_fields['max'] = array(
                        'title'             => __('At the latest', 'request-a-date'),
                        'type'              => 'number',
                        'description'       => __( 'The latest election could be so many days later', 'request-a-date'),
                        'desc_tip'          => false,
                        'css'               => 'width:80px;',
                        'default'           => $defaults['max']
                    );
                $this->form_fields['disableds'] = array(
                        'title'             => __('Disabled days', 'request-a-date'),
                        'type'              => 'text',
                        'description'       => __( 'Comma-separated list <em>(YYYY-MM-DD)</em>', 'request-a-date'),
                        'desc_tip'          => false,
                        'css'               => 'width:100%;',
                        'default'           => $defaults['disableds']
                    );
                $this->form_fields['on_days'] = array(
                        'title'             => __('Day\'s', 'request-a-date'),
                        'type'              => 'daylist',
                        'description'       => __( 'Select the days that are optional!', 'request-a-date'),
                        'desc_tip'          => false,
                        'default'           => $defaults['on_days']
                    );
                $this->form_fields['admin_column'] = array(
                        'title'             => __('Show column', 'request-a-date'),
                        'type'              => 'checkbox',
                        'description'       => __( 'Do you want to display it as a column when listing orders in backend?', 'request-a-date'),
                        'desc_tip'          => false,
                        'default'           => $defaults['admin_column']
                    );
                $this->form_fields['admin_info'] = array(
                        'title'             => __('Show in order', 'request-a-date'),
                        'type'              => 'checkbox',
                        'description'       => __( 'Show in order details in backend?', 'request-a-date'),
                        'desc_tip'          => false,
                        'default'           => $defaults['admin_column']
                    );
                $this->form_fields['add_thankyou'] = array(
                        'title'             => __('Show in thankyou', 'request-a-date'),
                        'type'              => 'checkbox',
                        'description'       => __( 'Show date in thakyou page?', 'request-a-date'),
                        'desc_tip'          => false,
                        'default'           => $defaults['add_thankyou']
                    );
                $this->form_fields['add_email'] = array(
                        'title'             => __('Show in email', 'request-a-date'),
                        'type'              => 'checkbox',
                        'description'       => __( 'Show date in email message?', 'request-a-date'),
                        'desc_tip'          => false,
                        'default'           => $defaults['add_email']
                    );

            }
            
            public function generate_daylist_html( $key, $data ) {
                
                $field = $this->plugin_id . $this->id . '_' . $key.'[]';
                $sets = $this->get_option( 'on_days' );    
                if (empty($sets)) {
                    $sets = explode(',', $data['defaults']);
                } else {
                    $sets = explode(',', $sets);
                }
                
                $html = array();
                $start_of_week = get_option( 'start_of_week' );

                $days = array(__('Sunday'),__('Monday'),__('Tuesday'),__('Wednesday'),__('Thursday'),__('Friday'),__('Saturday'));

                for ($i = $start_of_week; $i <= 6; $i++) {
                    
                    $val = $i;
                    if ($i == 0) { $val = 7; }
                    
                    $checked = '';
                    if (in_array($val, $sets)) { $checked = 'checked="checked"'; }
                    $html[] = '<input type="checkbox" '.$checked.' name="'.$field.'" value="'.$val.'" />&nbsp;'.$days[$i].'<br />';
                }
                for ($i = 0; $i < $start_of_week; $i++) {
                    $val = $i;
                    if ($i == 0) { $val = 7; }

                    $checked = '';
                    if (in_array($val, $sets)) { $checked = 'checked="checked"'; }
                    $html[] = '<input type="checkbox" '.$checked.' name="'.$field.'" value="'.$val.'" />&nbsp;'.$days[$i].'<br />';
                }
            	ob_start();
            	?>
            	<tr valign="top">
            		<th scope="row" class="titledesc">
            			<label for="<?php echo esc_attr( $field ); ?>"><?php echo wp_kses_post( $data['title'] ); ?></label>
            			<?php echo $this->get_tooltip_html( $data ); ?>
            		</th>
            		<td class="forminp">
            			<fieldset>
                            <?php 
                                echo implode('', $html);
            				    echo $this->get_description_html( $data );
                            ?>
            			</fieldset>
            		</td>
            	</tr>
            	<?php
            	return ob_get_clean();    
            }

            public function generate_ships_html( $key, $data ) {

                global $wpdb;

                $field = $this->plugin_id . $this->id . '_' . $key.'[]';

                $sets = $this->get_option( 'use_shipping' );
                if (empty($sets)) {
                    $sets = array();
                } else {
                    $sets = explode(',', $sets);
                }
                
                $wpdb->show_errors = true;
                $table_name = $wpdb->prefix . 'woocommerce_shipping_zones'; 
                $query = 'SELECT * FROM `'.$table_name.'` ORDER BY `zone_order` ASC';
                $zones = $wpdb->get_results($query); 
                
                $outer_zone = WC_Shipping_Zones::get_zone(0);
                $zone_data = $outer_zone->get_data(); 
                $shippings = $outer_zone->get_shipping_methods();    

                if (!empty($shippings)) {
                    $outer = new stdClass();
                    $outer->zone_id = 0;
                    $outer->zone_name = $zone_data['zone_name'];
                    $zones[] = $outer;
                }

                $html = array();
                if (!empty($zones)) {
                    
                    foreach ($zones as &$zone) {
                        $html[] = '<h4 style="margin:6px;">' . $zone->zone_name . '</h4><div style="margin-left:30px;">';
                        
                        $outer_zone = WC_Shipping_Zones::get_zone($zone->zone_id);
                        $methods = $outer_zone->get_shipping_methods(); 
                        
                        if (!empty($methods)) {
                            foreach ($methods as $method) {

                            $icon = '';
                            if ($method->enabled == 'no') {
                                $icon = '<span class="dashicons dashicons-hidden"></span>&nbsp;';
                            }

            
                                switch ($method->id){ 
        
                                	case 'flexible_shipping':
                                        $method_options = get_option('flexible_shipping_methods_'.$method->instance_id);
                                        if (!empty($method_options)) {
                                            
                                            foreach ($method_options as $method_item) {
                                        
                                                $checked = '';
                                                if (in_array($method_item['id_for_shipping'], $sets)) {
                                                    $checked = 'checked="checked"';
                                                }
                                                $html[] = $icon . '<input type="checkbox" '.$checked.' name="'.$field.'" value="'.$method_item['id_for_shipping'].'" />&nbsp;' . $method_item['method_title'] . '<br />';        
                                            }
                                            
                                        }
                                        break;
                                
                                    case 'pickpack_package_point':
                                        $checked = '';
                                        if (in_array('pickpack_package_point:'.$method->instance_id, $sets)) {
                                            $checked = 'checked="checked"';
                                        }
                                        $method_options = get_option('woocommerce_pickpack_package_point_'.$method->instance_id.'_settings');
                                        if (!empty($method_options)) {
                                            $html[] = $icon . '<input type="checkbox" '.$checked.' name="'.$field.'" value="pickpack_package_point:'.$method->instance_id.'" />&nbsp;' . $method_options['title'] . '<br />';
                                        }                                                                       	
                                        break;
        
                                    case 'flat_rate':
                                        $checked = '';
                                        if (in_array('flat_rate:'.$method->instance_id, $sets)) {
                                            $checked = 'checked="checked"';
                                        }
                                        $method_options = get_option('woocommerce_flat_rate_'.$method->instance_id.'_settings');
                                        if (!empty($method_options)) {
                                            $html[] = $icon . '<input type="checkbox" '.$checked.' name="'.$field.'" value="flate_rate:'.$method->instance_id.'" />&nbsp;' . $method_options['title'] . '<br />';
                                        } else {
                                            $html[] = $icon . '<input type="checkbox" '.$checked.' name="'.$field.'" value="flate_rate:'.$method->instance_id.'" />&nbsp;' . __(ucfirst(str_replace('_', ' ', $method->id)), 'woocommerce') . '<br />';
                                        }
                                        break;
        
                                    case 'free_shipping':
                                        $checked = '';
                                        if (in_array('free_shipping:'.$method->instance_id, $sets)) {
                                            $checked = 'checked="checked"';
                                        }
                                        $method_options = get_option('woocommerce_free_shipping_'.$method->instance_id.'_settings');
                                        if (!empty($method_options)) {
                                            $html[] = $icon . '<input type="checkbox" '.$checked.' name="'.$field.'" value="free_shipping:'.$method->instance_id.'" />&nbsp;' . $method_options['title'] . '<br />';
                                        } else {
                                            $html[] = $icon . '<input type="checkbox" '.$checked.' name="'.$field.'" value="free_shipping:'.$method->instance_id.'" />&nbsp;' . __(ucfirst(str_replace('_', ' ', $method->id)), 'woocommerce') . '<br />';                                    
                                        }
                                        break;
        
                                    case 'local_pickup':
                                        $checked = '';
                                        if (in_array('local_pickup:'.$method->instance_id, $sets)) {
                                            $checked = 'checked="checked"';
                                        }
                                        $method_options = get_option('woocommerce_local_pickup_'.$method->instance_id.'_settings');
                                        if (!empty($method_options)) {
                                            $html[] = $icon . '<input type="checkbox" '.$checked.' name="'.$field.'" value="local_pickup:'.$method->instance_id.'" />&nbsp;' . $method_options['title'] . '<br />';
                                        } else {
                                            $html[] = $icon . '<input type="checkbox" '.$checked.' name="'.$field.'" value="local_pickup:'.$method->instance_id.'" />&nbsp;' . __(ucfirst(str_replace('_', ' ', $method->id)), 'woocommerce') . '<br />';                                    
                                        }
                                        break;
        
                                	default :
                                    
                                        $checked = '';
                                        if (in_array($method->id.':'.$method->instance_id, $sets)) {
                                            $checked = 'checked="checked"';
                                        }
                                        $method_options = get_option('woocommerce_'.$method->id.'_'.$method->instance_id.'_settings');
                                        
                                        if (!empty($method_options)) {
                                            $title = '';
                                            if (isset($method_options['title'])) {
                                                $title = $method_options['title'];
                                            }
                                            if (isset($method_options['method_title'])) {
                                                $title = $method_options['method_title'];
                                            }
            
                                            if (!empty($method_options)) {
                                                $html[] = $icon . '<input type="checkbox" '.$checked.' name="'.$field.'" value="'.$method->id.':'.$method->instance_id.'" />&nbsp;' . $title . '<br />';
                                            } else {
                                                $html[] = $icon . '<input type="checkbox" '.$checked.' name="'.$field.'" value="'.$method->id.':'.$method->instance_id.'" />&nbsp;' . __(ucfirst(str_replace('_', ' ', $method->method_id)), 'woocommerce') . '<br />';                                    
                                            }
                                        } else {
                                            $html[] = __('Unknown delivery method! If you have a problem, contact the developer!','request-a-date') . '&nbsp;<small><em>('.$method->id.')</em></small>' . '<br />';
                                        }
                                    
                                }
                            
                            }
                        }
                        
                        $html[] = '</div>';
                    }
                }

                
            	ob_start();
            	?>
            	<tr valign="top">
            		<th scope="row" class="titledesc">
            			<label for="<?php echo esc_attr( $field ); ?>"><?php echo wp_kses_post( $data['title'] ); ?></label>
            			<?php echo $this->get_tooltip_html( $data ); ?>
            		</th>
            		<td class="forminp">
            			<fieldset>
                            <?php if (empty($zones)) {
                                echo '<span style="color:#FF0000">' . 
                                     __( 'There are no WooCommerce delivery zones set. Be the first to set up delivery zones and modes.', 'request-a-date' ) .
                                     '</span>';
                            } else {
                                echo implode('', $html);
            				    echo $this->get_description_html( $data );
                            }
                            ?>
            			</fieldset>
            		</td>
            	</tr>
            	<?php
            	return ob_get_clean();    
            }        

            public function validate_daylist_field( $key, $value ) {
                
                if (!empty($value)) {
                    $value = implode(',', $value);
                } else {
                    $value = '';
                }
            
                return $value;
            }            
            
            public function validate_ships_field( $key, $value ) {
                
                if (!empty($value)) {
                    $value = implode(',', $value);
                } else {
                    $value = '';
                }
            
                return $value;
            }            

        }
    }
