<?php
/*
Plugin Name: Request a date on the WooCommerce checkout page
Plugin URI:  http://wpdemo.dovi42.hu/request-a-date-en
Description: Request a date in the WooCommerce payment page.
Version:     1.10
Tested up to: 5.8
Author:      Dovi42
Author URI:  http://dovi42.hu/
License:     GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: request-a-date
WC requires at least: 4.0.0
WC tested up to: 8.2.1
Generator:   WP Creator - http://wpcreator.hu - 2020-11-24 10:15:43
*/

if ( !defined( 'ABSPATH' ) ) exit;

if (!defined('DS')) { define( 'DS', DIRECTORY_SEPARATOR ); }

define('REQUEST_A_DATE_403_ROOT', dirname(__FILE__));
define('REQUEST_A_DATE_403_VERSION', '1.10');

function request_a_date_403_update() {
    require_once ( dirname(__file__) .DIRECTORY_SEPARATOR. 'libs' .DIRECTORY_SEPARATOR. 'autoupdate.php' ); 
	
	$plugin_current_version = REQUEST_A_DATE_403_VERSION; // Current version
	$plugin_remote_path     = 'http://update.dovi42.hu/request-a-date/update.php';  
	$plugin_slug            = plugin_basename(__file__);
	$license_user           = get_site_url();
	$license_key            = '<optional license key>';

	if ( $license_user && $license_key && $plugin_remote_path )
	{
		new request_a_date_403_AutoUpdate ($plugin_current_version, $plugin_remote_path, $plugin_slug, $license_user, $license_key);
	}
}
add_action('init', 'request_a_date_403_update');

function request_a_date_403_get_options() { 
	// Alapértelmezett értékek beállítása
	// Set default option values
	$defaults = array(
			'woocommerce_checkout' => '',
            'use_shipping'         => '',
			'in_table'             => 'yes',
			'title'                => __('Select date:', 'request-a-date'),
			'description'          => '',
            'date_format'          => 'Y. F j., l',
			'intime'               => '12:00',
			'shift'                => 1,
            'reorder'              => 0, 
			'max'                  => 14,
			'disableds'            => '',
			'on_weeks'             => '',
			'on_days'              => '1,2,3,4,5',
            'admin_column'         => 'yes', 
            'admin_info'           => 'yes',
            'add_thankyou'         => 'yes',
            'add_email'            => 'yes'
		);

	// Beállított értékek beolvasása
	// Get the set plugin option values
	$options = get_option('woocommerce_request_a_date_settings');
    if ((isset($options['on_weeks'])) and ($options['on_weeks'] == 'yes')) {
        $options['on_days'] == '1,2,3,4,5,6,7'; 
    }

	// Ha nincs beállítva, akkor az alapértelmezett érték 
	// If not set then set the default 
	$options = wp_parse_args($options, $defaults);

	return $options;
}


function request_a_date_403_load_textdomain() {
    load_plugin_textdomain( 'request-a-date', false, basename( dirname( __file__ )) . '/languages' ); 
}
add_action( 'plugins_loaded', 'request_a_date_403_load_textdomain' );

function request_a_date_403_activation() {
    // A plugin aktiválásakor fut le
    // Call when plugin is activated
    
	// Alapértelmezett értékek beállítása
	// Set default value(s) to options
	$options = request_a_date_403_get_options();
	update_option('woocommerce_request_a_date_settings', $options, true);
    
}
register_activation_hook( __file__, 'request_a_date_403_activation' );

function request_a_date_403_deactivation() {
    // A plugin deaktiválásakor fut le
    // Call when plugin is deactivated

	// Beállítások törlése
	// Delete value(s) from options
	delete_option('woocommerce_request_a_date_settings');

}
register_deactivation_hook( __file__, 'request_a_date_403_deactivation' );


if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
    define('REQUEST_A_DATE_403_WOOCOMMERCE_ACTIVE', 1);
} else {
    define('REQUEST_A_DATE_403_WOOCOMMERCE_ACTIVE', 0);
}

function request_a_date_403_styles_and_scripts_to_frontend()
{
    wp_register_style( 'request-a-date', plugins_url( 'request-a-date/assets/css/request-a-date.css', REQUEST_A_DATE_403_ROOT ) );
	wp_enqueue_style( 'request-a-date' );
    
	wp_register_script('request-a-date-js', plugins_url( 'request-a-date/assets/js/request-a-date.js', REQUEST_A_DATE_403_ROOT ), array('jquery'), false, true);

	// Ajax hívás engedélyezése
	// Enable call ajax
	wp_localize_script('request-a-date-js', 'request_a_date_403_ajax_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
    // wp_localize_script('request-a-date-js', 'request_a_date_updating_text', __('Updating, please wait ...', 'request-a-date'));
    wp_add_inline_script('request-a-date-js', 'var request_a_date_updating_text = "'.__('Updating, please wait ...', 'request-a-date').'";', 'before' );
	wp_enqueue_script('request-a-date-js');
}
// add_action( 'wp_enqueue_scripts', 'request_a_date_403_styles_and_scripts_to_frontend' );

if ( is_admin() ){ 

    if (REQUEST_A_DATE_403_WOOCOMMERCE_ACTIVE) {
    
        if ( ! class_exists( 'WC_request_a_date_plugin' ) ) {
        
            class WC_request_a_date_plugin {
        
                public function __construct() {
                    add_action( 'plugins_loaded', array( $this, 'init' ) );
                }
            
                public function init() {
                    if ( class_exists( 'WC_Integration' ) ) {
                        include( dirname(__file__) .DIRECTORY_SEPARATOR. 'libs' .DIRECTORY_SEPARATOR. 'class.php' );
                        add_filter( 'woocommerce_integrations', array( $this, 'add_integration' ) );
                    }
                }
            
                public function add_integration( $integrations ) {
                    $integrations[] = 'request_a_date_403_settings';
                    return $integrations;
                }
            }
            $WC_request_a_date_plugin = new WC_request_a_date_plugin( __FILE__ );
        }

        require_once REQUEST_A_DATE_403_ROOT .DS. 'libs' .DS. 'woo-admin.php';
        
    }

    function request_a_date_403_get_extra_meta_links($meta, $file, $data, $status) {

        if (plugin_basename(__FILE__) == $file) {

            $meta[]  = '<a href="https://wordpress.org/support/plugin/request-a-date/reviews/">'.
                       __('Please rating!', 'request-a-date').'</a>';
        }
        return $meta;
    }
    add_filter("plugin_row_meta", 'request_a_date_403_get_extra_meta_links', 10, 4);
    
} else {

    if (REQUEST_A_DATE_403_WOOCOMMERCE_ACTIVE) {

        $id = get_option('woocommerce_checkout_page_id');
        $slug = get_post_field( 'post_name', $id );
        $current = trim($_SERVER['REQUEST_URI'], DIRECTORY_SEPARATOR);
        
        if ($slug == $current) {
            add_action( 'wp_enqueue_scripts', 'request_a_date_403_styles_and_scripts_to_frontend' ); 
            require_once REQUEST_A_DATE_403_ROOT .DS. 'libs' .DS. 'woo.php';
        }       
    }
}

// Add settings link to plugins page 
function request_a_date_403_add_settings_link( $links ) {
    if (REQUEST_A_DATE_403_WOOCOMMERCE_ACTIVE) {
        $settings_link = '<a href="admin.php?page=wc-settings&tab=integration&section=request_a_date">' . __( 'Settings' ) . '</a>';
    } else {
        $settings_link = '<span style="color:#a00;">' . __( 'The plugin needs the WooCommerce plugin!', 'request-a-date' ) . '</span>';
    }
    array_unshift( $links, $settings_link );
  	return $links;
}
$plugin = plugin_basename( __file__ );
add_filter( "plugin_action_links_$plugin", 'request_a_date_403_add_settings_link' );

add_action( 'before_woocommerce_init', function() {
	if ( class_exists( \Automattic\WooCommerce\Utilities\FeaturesUtil::class ) ) {
		\Automattic\WooCommerce\Utilities\FeaturesUtil::declare_compatibility( 'custom_order_tables', __FILE__, false );
	}
} );

if (REQUEST_A_DATE_403_WOOCOMMERCE_ACTIVE) {
    include(REQUEST_A_DATE_403_ROOT . '/libs/ajax.php');
    include(REQUEST_A_DATE_403_ROOT . '/libs/hooks.php');
}
